==> koffice-trinity-3.5.13.2.tar.xz: koffice-trinity-3.5.13.2/lib/kotext/KoFontTab.cpp <==
/* This file is part of the KDE project
   Copyright (C)  2001, 2002 Montel Laurent <lmontel@mandrakesoft.com>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
*/

#include "KoFontTab.h"

KoFontTab::KoFontTab( uint fontListCriteria, TQWidget* parent, const char* name, WFlags fl ) 
        : KoFontTabBase( parent, name, fl )
{
    TQStringList list;
    KFontChooser_local::getFontList(list, fontListCriteria);

    characterFont->setFamilyList( list );
    comparisonFont = characterFont->font();
    connect( characterFont, TQT_SIGNAL( fontSelected( const TQFont & ) ), this, TQT_SLOT( slotFontChanged( const TQFont & ) ) );
}

KoFontTab::~KoFontTab()
{
}

TQFont KoFontTab::getSelection()
{
    return characterFont->font();
}

void KoFontTab::setSelection( const TQFont &font )
{
    characterFont->setFont( font );
}

void KoFontTab::slotFontChanged( const TQFont &font )
{
    if ( comparisonFont.family() != font.family() ) emit familyChanged();
    if ( comparisonFont.bold() != font.bold() ) emit boldChanged();
    if ( comparisonFont.italic() != font.italic() ) emit italicChanged();
    if ( comparisonFont.pointSize() != font.pointSize() ) emit sizeChanged();
    comparisonFont = font;
}

#include "KoFontTab.moc"

==> koffice-trinity_14.0.8.orig.tar.xz: koffice-trinity-14.0.8/lib/kotext/KoFontTab.cpp <==
/* This file is part of the KDE project
   Copyright (C)  2001, 2002 Montel Laurent <lmontel@mandrakesoft.com>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
*/

#include "KoFontTab.h"

KoFontTab::KoFontTab( uint fontListCriteria, TQWidget* parent, const char* name, WFlags fl ) 
        : KoFontTabBase( parent, name, fl )
{
    TQStringList list;
    TDEFontChooser_local::getFontList(list, fontListCriteria);

    characterFont->setFamilyList( list );
    comparisonFont = characterFont->font();
    connect( characterFont, TQT_SIGNAL( fontSelected( const TQFont & ) ), this, TQT_SLOT( slotFontChanged( const TQFont & ) ) );
}

KoFontTab::~KoFontTab()
{
}

TQFont KoFontTab::getSelection()
{
    return characterFont->font();
}

void KoFontTab::setSelection( const TQFont &font )
{
    characterFont->setFont( font );
}

void KoFontTab::slotFontChanged( const TQFont &font )
{
    if ( comparisonFont.family() != font.family() ) emit familyChanged();
    if ( comparisonFont.bold() != font.bold() ) emit boldChanged();
    if ( comparisonFont.italic() != font.italic() ) emit italicChanged();
    if ( comparisonFont.pointSize() != font.pointSize() ) emit sizeChanged();
    comparisonFont = font;
}

#include "KoFontTab.moc"
